==> tetzle_2.1.6.orig.tar.gz: tetzle-2.1.6/translations/tetzle_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Открыть изображение</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Вид</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Опции</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Видимые границы</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Убрать тени</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Цвета</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Задний фон</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Тень</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Подсветка</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Изображение отсутствует.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Пожалуйста, подождите</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Загрузка изображения...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Генерация пазла...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Создание пазлов...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Загрузка пазла...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Неизвестный формат файла</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Неизвестный элемент &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Ошибка при обработке XML-файла.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Загрузка пазлов...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Перемешиваем пазлы...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Размещение пазлов...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Успех!</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Выберите игру</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Текущие игры</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Новая игра</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Настройки изображения</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Тэги:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Выберите язык программы:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Язык системы&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Пожалуйста, перезапустите программу для того, чтобы изменения вступили в силу.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Добавить изображение</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Удалить изображение</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Настройки изображения</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 пазлов</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Копируем изображения...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Удалить выбранное изображение?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Удалить выбранное изображение?

Сохраненные игры, использующие это изображение, также будут удалены.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Без названия</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Без названия</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 пазлов %2 %3% завершено</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Удалить игру</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Удалить выбранную игру?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Общий вид</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Добавить тэг</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Удалить тэг</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Нет тега</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Все изображения</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Без названия %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Удалить выбранный тэг?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Такой тэг уже существует.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Перемешать пазлы</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Выбрать...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>У&amp;величить</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>У&amp;меньшить</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>Наилучший вид</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Показывать &amp;общий вид</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;На весь экран</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Н&amp;астройки</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Вид...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Язык...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Управление</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Об игре</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О Qt&amp;</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Управление</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Брать пазлы:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Левый клик или пробел</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Отпускать пазлы:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Выделять пазлы&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Зажать левую кнопку мыши и выделять</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Вращение элементов:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Правый клик, Ctrl + левый клик, или R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Двигать полотно пазла:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Зажать колесико мышки, Shift+ Левый клик, или кнопки Влево, Вправо, Вверх и Вниз</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Увеличить пазл:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Колесо прокрутки или +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Двигать курсор:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Мышь или W,A,S,D</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>О Tetlze</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Игра-головоломка с тетрамино</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Копирайт &amp;copy; 20080%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Опубликовано под лицензией &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> tetzle_3.0.1.orig.tar.gz: tetzle-3.0.1/translations/tetzle_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Открыть изображение</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Вид</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Опции</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Видимые границы</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Убрать тени</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Цвета</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Задний фон</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Тень</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Подсветка</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Изображение отсутствует.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Пожалуйста, подождите</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Загрузка изображения...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Генерация пазла...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Создание пазлов...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Загрузка пазла...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Неизвестный формат файла</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Неизвестный элемент &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Ошибка при обработке XML-файла.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Загрузка пазлов...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Перемешиваем пазлы...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Размещение пазлов...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Успех!</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Выберите игру</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Текущие игры</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Новая игра</translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Настройки изображения</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Тэги:</translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Выберите язык программы:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Язык системы&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Пожалуйста, перезапустите программу для того, чтобы изменения вступили в силу.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Добавить изображение</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Удалить изображение</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Настройки изображения</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 пазлов</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Копируем изображения...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Без названия</translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Без названия</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 пазлов %2 %3% завершено</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Удалить игру</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Удалить выбранную игру?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Общий вид</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Добавить тэг</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Удалить тэг</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Нет тега</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Все изображения</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Без названия %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Удалить выбранный тэг?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Такой тэг уже существует.</translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Перемешать пазлы</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Выбрать...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>У&amp;величить</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>У&amp;меньшить</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>Наилучший вид</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Показывать &amp;общий вид</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;На весь экран</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Н&amp;астройки</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Вид...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Язык...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Управление</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Об игре</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О Qt&amp;</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Управление</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Брать пазлы:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Левый клик или пробел</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Отпускать пазлы:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Выделять пазлы&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Зажать левую кнопку мыши и выделять</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Вращение элементов:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Правый клик, Ctrl + левый клик, или R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Двигать полотно пазла:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Зажать колесико мышки, Shift+ Левый клик, или кнопки Влево, Вправо, Вверх и Вниз</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Увеличить пазл:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Колесо прокрутки или +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Двигать курсор:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Мышь или W,A,S,D</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>О Tetlze</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Игра-головоломка с тетрамино</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Копирайт &amp;copy; 20080%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Опубликовано под лицензией &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
